@@ -17,7 +17,7 @@ class Slide(Orderable):
     page = models.ForeignKey(Page, null=True, blank=True)
     target = models.URLField(null=True, blank=True)
     file = FileField(_('File'), max_length=200, upload_to='galleries', format='Image')
-    title = models.TextField(_('Description'), blank=True)
+    title = models.TextField(_('Title'), blank=True)
     description = models.TextField(_('Description'), blank=True)
 
     class Meta:
